@@ -19,7 +19,7 @@ Examples:
     Get the value for red:
 
     >>> palette.red
-    HexRGB('#ff0000')
+    Hex('#ff0000')
 
     Get names of all colors:
 
@@ -48,13 +48,21 @@ from pathlib import Path
 from typing import Union, List
 from warnings import warn
 
-from .color import ColorBase, sRGB, HSL, simplified_dist, random_color, HSV, color_str
-from .color_format import ColorFormat, ColorLike
 from . import config
+from . import utils
+from .color_class import ColorBase, sRGB, HSL, HSV
+from .color_format import ColorFormat, ColorLike
 
 _throw_exception = object()
 _builtin_palettes_dir = Path(__file__).resolve().parent / "builtin_palettes"
 
+__all__ = [
+    "Palette",
+    "StackPalette",
+    "find_palettes",
+    "delete_palette"
+]
+
 
 class Palette:
     """Class that holds colors values associated with names.
@@ -62,7 +70,7 @@ class Palette:
     Examples:
         >>> palette = Palette(red="#ff0000") # Uses default color format
         >>> palette.red
-        HexRGB('#ff0000')
+        Hex('#ff0000')
 
         For more examples see the documentation of the :mod:`~colorir.palette` module.
 
@@ -87,17 +95,17 @@ class Palette:
             self.add(k, v)
 
     @property
-    def colors(self):
+    def colors(self) -> List[ColorBase]:
         """colors: A list of all color values currently stored in the :class:`Palette`."""
         return list(self._color_dict.values())
 
     @property
-    def color_names(self):
+    def color_names(self) -> List[str]:
         """colors: A list of all color names currently stored in the :class:`Palette`."""
         return list(self._color_dict.keys())
 
     @property
-    def color_format(self):
+    def color_format(self) -> ColorFormat:
         """color_format: Color format specifying how the colors of this :class:`Palette` are
         stored.
         """
@@ -120,7 +128,7 @@ class Palette:
              name: str = None,
              color_format: ColorFormat = None,
              warnings=True):
-        """Factory method that loads previously created palettes into a :class:`Palettes` instance.
+        """Factory method that loads previously created palettes into a :class:`Palette` instance.
 
         A palette is a file containing json-formatted information about colors that ends with the
         '.palette' extension. You should not create such files manually but rather through the
@@ -135,7 +143,7 @@ class Palette:
             palettes: List of palettes located in the location represented by `palettes_dir` that
                 should be loaded by this :class:`Palette` instance. Additionally may include
                 built-in palettes such as 'css' if `search_builtins` is set to ``True``. If this
-                parameter is a string, the :attr:`Palettes.name` will be inferred from it. By
+                parameter is a string, the :attr:`Palette.name` will be inferred from it. By
                 default, loads all palettes found in the specified directory.
             palettes_dir: The directory from which the palettes specified in the `palettes`
                 parameter will be loaded. Defaults to the value specified in
@@ -237,13 +245,13 @@ class Palette:
         Examples:
             >>> palette = Palette(red="#ff0000", blue="#0000ff")
             >>> palette.get_color("red")
-            HexRGB('#ff0000')
+            Hex('#ff0000')
             >>> palette.get_color(["red", "blue"])
-            [HexRGB('#ff0000'), HexRGB('#0000ff')]
+            [Hex('#ff0000'), Hex('#0000ff')]
 
         Returns:
-            A single :class:`~colorir.color.ColorBase` if `name` is a string or a list of
-            :class:`~colorir.color.ColorBase` if `name` is a list of strings.
+            A single :class:`~colorir.color_class.ColorBase` if `name` is a string or a list of
+            :class:`~colorir.color_class.ColorBase` if `name` is a list of strings.
         """
         if fallback is _throw_exception:
             if isinstance(name, str):
@@ -261,8 +269,8 @@ class Palette:
 
         Args:
             color: The value of the color to be searched for. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that resembles
-                the color you want to search for.
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
+                resembles the color you want to search for.
 
         Examples:
             >>> palette = Palette(red="#ff0000")
@@ -280,24 +288,24 @@ class Palette:
         """Finds the `n` most similar colors to `color` in this palette.
 
         For more details on the algorithm implemented to calculate similarity, see
-        :func:`color.simplified_dist() <colorir.color.simplified_dist()>` documentation.
+        :func:`~colorir.utils.simplified_dist()` documentation.
 
         Args:
             color: The value of the color of reference. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that resembles
-                the color to which others will be compared in search of similar results.
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
+                resembles the color to which others will be compared in search of similar results.
             n: How many similar colors to be retrieved. -1 means all colors from the palette will
                 be returned from most similar to least.
 
         Examples:
             >>> palette = Palette(red="#ff0000", blue="#0000ff")
             >>> palette.most_similar("#880000")
-            HexRGB('#ff0000')
+            Hex('#ff0000')
 
         Returns:
-            A single :class:`~colorir.color.ColorBase` if `n` == 1 or a list of
-            :class:`~colorir.color.ColorBase` if n != 1. If the return type is a list, the colors
-            will be ordered from most similar to least.
+            A single :class:`~colorir.color_class.ColorBase` if `n` == 1 or a list of
+            :class:`~colorir.color_class.ColorBase` if `n` != 1. If the return type is a list, the
+            colors will be ordered from most similar to least.
         """
         return _most_similar(self, color, n)
 
@@ -311,8 +319,8 @@ class Palette:
         Args:
             name: Name to be assigned to the new color.
             color: The value of the color to be created. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that resembles
-                the color you want to add.
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
+                resembles the color you want to add.
 
         Examples:
             Adding a new blue color to the palette:
@@ -320,7 +328,7 @@ class Palette:
             >>> palette = Palette()
             >>> palette.add("bestblue", "4287f5")
             >>> palette.bestblue
-            HexRGB('#4287f5')
+            Hex('#4287f5')
         """
         # Test to detect invalid color names
         if name in dir(self):
@@ -335,7 +343,7 @@ class Palette:
         Args:
             name: Name of the color to be updated.
             color: The value of the color to be updated. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
                 resembles the format of the color you want to update.
 
         Examples:
@@ -343,13 +351,13 @@ class Palette:
             
             >>> palette = Palette(myred="dd0000")
             >>> palette.myred
-            HexRGB('#dd0000')
+            Hex('#dd0000')
             
             Change it to be even a bit darker:
             
             >>> palette.update("myred", "800000")
             >>> palette.myred
-            HexRGB('#800000')
+            Hex('#800000')
         """
         if name in self._color_dict:
             self._color_dict[name] = self.color_format.format(color)
@@ -397,7 +405,7 @@ class Palette:
         with open(Path(palettes_dir) / (self.name + ".palette"), "w") as file:
             formatted_colors = {}
             for c_name, c_val in self._color_dict.items():
-                c_rgba = "#%02x" % c_val._rgba[-1] + "%02x%02x%02x" % c_val._rgba[:3]
+                c_rgba = c_val.hex(include_a=True, tail_a=False)
                 formatted_colors[c_name] = c_rgba
             json.dump(formatted_colors, file, indent=4)
 
@@ -405,6 +413,19 @@ class Palette:
         """Converts this palette into a :class:`StackPalette`."""
         return StackPalette(self.name, self.color_format, *self._color_dict.values())
 
+    def to_cmap(self, N: int = None):
+        """Converts this palette into a matplotlib ListedColormap.
+
+        Args:
+            N: Passed down to ListedColormap constructor.
+        """
+        from matplotlib.colors import ListedColormap
+
+        colors = [color.hex(include_a=True, tail_a=True) for color in self.colors]
+        if self.name is None:
+            return ListedColormap(colors, N=N)
+        return ListedColormap(colors, N=N, name=self.name)
+
 
 class StackPalette:
     """Class that handles anonymous indexed colors stored as a stack.
@@ -415,7 +436,7 @@ class StackPalette:
     Examples:
         >>> spalette = StackPalette("elementary", None, "ff0000", "00ff00", "0000ff")
         >>> spalette[0]
-        HexRGB('#ff0000')
+        Hex('#ff0000')
 
     Args:
         name: Name of the palette which will be used to save it with
@@ -440,12 +461,12 @@ class StackPalette:
             self.add(color)
 
     @property
-    def colors(self):
+    def colors(self) -> List[ColorBase]:
         """colors: A list of all color values currently stored in the :class:`StackPalette`."""
         return list(self._color_stack)
 
     @property
-    def color_format(self):
+    def color_format(self) -> ColorFormat:
         """color_format: Color format specifying how the colors of this :class:`StackPalette` are
         stored.
         """
@@ -463,6 +484,7 @@ class StackPalette:
     def load(cls,
              palettes: Union[str, List[str]] = None,
              palettes_dir: str = None,
+             search_builtins=True,
              name: str = None,
              color_format: ColorFormat = None):
         """Factory method that loads previously created stack palettes into a
@@ -480,11 +502,14 @@ class StackPalette:
         Args:
             palettes: List of stack palettes located in the location represented by `palettes_dir`
                 that should be loaded by this :class:`StackPalette` instance. If this parameter is
-                a string, the :attr:`StackPalettes.name` will be inferred from it. By default,
+                a string, the :attr:`StackPalette.name` will be inferred from it. By default,
                 loads all palettes found in the specified directory.
             palettes_dir: The directory from which the palettes specified in the `palettes`
                 parameter will be loaded. Defaults to the value specified in
                 :data:`config.DEFAULT_PALETTES_DIR <colorir.config.DEFAULT_PALETTES_DIR>`.
+            search_builtins: Whether `palettes` also includes built-in palettes such as 'tab10' or
+                'dark2'. Set to ``False`` to ensure only palette files found in `palettes_dir` are
+                loaded.
             name: Name of the palette which will be used to save it with the
                 :meth:`StackPalette.save()`. If the `palettes` parameter is a single string,
                 defaults to that.
@@ -494,15 +519,21 @@ class StackPalette:
         """
         if palettes_dir is None:
             palettes_dir = config.DEFAULT_PALETTES_DIR
+        palettes_dir = [palettes_dir]
+        if search_builtins:
+            palettes_dir.append(_builtin_palettes_dir)
         if isinstance(palettes, str):
             if name is None:
                 name = palettes
             palettes = [palettes]
 
         found_palettes = {}
-        for palette_file in Path(palettes_dir).glob("*.spalette"):
-            palette_name = palette_file.name.replace(".spalette", '')
-            found_palettes[palette_name] = json.loads(palette_file.read_text())
+        for path in palettes_dir:
+            path = Path(path)
+            palette_files = path.glob("*.spalette")
+            for palette_file in palette_files:
+                palette_name = palette_file.name.replace(".spalette", '')
+                found_palettes[palette_name] = json.loads(palette_file.read_text())
 
         palette_obj = cls(name=name, color_format=color_format)
         if palettes is None: palettes = list(found_palettes)
@@ -533,7 +564,7 @@ class StackPalette:
 
              >>> spalette = StackPalette.new_complementary(2, sRGB(255, 0, 0))
              >>> spalette
-             StackPalette(HexRGB('#ff0000'), HexRGB('#00ffff'))
+             StackPalette(Hex('#ff0000'), Hex('#00ffff'))
 
              Make a tetradic palette of random colors:
 
@@ -551,7 +582,7 @@ class StackPalette:
         """
         n_spalette = cls(name=name, color_format=color_format)
         if color is None:
-            hsv = random_color(color_format=ColorFormat(HSV, max_h=360))
+            hsv = utils.random_color(color_format=ColorFormat(HSV, max_h=360))
         else:
             hsv = n_spalette.color_format.format(color).hsv(max_h=360)
 
@@ -578,7 +609,7 @@ class StackPalette:
 
              >>> spalette = StackPalette.new_analogous(2, start=1, color=sRGB(255, 0, 0))
              >>> spalette
-             StackPalette(HexRGB('#ff0000'), HexRGB('#ff8000'))
+             StackPalette(Hex('#ff0000'), Hex('#ff8000'))
 
              Make a palette of four similar colors:
 
@@ -615,7 +646,7 @@ class StackPalette:
 
         n_spalette = cls(name=name, color_format=color_format)
         if color is None:
-            hsv = random_color(color_format=ColorFormat(HSV, max_h=360))
+            hsv = utils.random_color(color_format=ColorFormat(HSV, max_h=360))
         else:
             hsv = n_spalette.color_format.format(color).hsv(max_h=360)
 
@@ -654,24 +685,24 @@ class StackPalette:
         """Finds the `n` most similar colors to `color` in this palette.
 
         For more details on the algorithm implemented to calculate similarity, see
-        :func:`color.simplified_dist() <colorir.color.simplified_dist()>` documentation.
+        :func:`~colorir.utils.simplified_dist()` documentation.
 
         Args:
             color: The value of the color of reference. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that resembles
-                the color to which others will be compared in search of similar results.
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
+                resembles the color to which others will be compared in search of similar results.
             n: How many similar colors to be retrieved. -1 means all colors from the palette will
                 be returned from most similar to least.
 
         Examples:
             >>> spalette = StackPalette(None, None, "#ff0000", "#0000ff")
             >>> spalette.most_similar("#880000")
-            HexRGB('#ff0000')
+            Hex('#ff0000')
 
         Returns:
-            A single :class:`~colorir.color.ColorBase` if `n` == 1 or a list of
-            :class:`~colorir.color.ColorBase` if n != 1. If the return type is a list, the colors
-            will be ordered from most similar to least.
+            A single :class:`~colorir.color_class.ColorBase` if `n` == 1 or a list of
+            :class:`~colorir.color_class.ColorBase` if `n` != 1. If the return type is a list, the
+            colors will be ordered from most similar to least.
         """
         return _most_similar(self, color, n)
 
@@ -683,10 +714,10 @@ class StackPalette:
         Examples:
             >>> spalette = StackPalette(None, None, "ff0000", "0000ff")
             >>> spalette
-            StackPalette(HexRGB('#ff0000'), HexRGB('#0000ff'))
+            StackPalette(Hex('#ff0000'), Hex('#0000ff'))
             >>> spalette.swap(0, 1)
             >>> spalette
-            StackPalette(HexRGB('#0000ff'), HexRGB('#ff0000'))
+            StackPalette(Hex('#0000ff'), Hex('#ff0000'))
 
         Args:
             index1: The index of the first color.
@@ -704,8 +735,8 @@ class StackPalette:
 
         Args:
             color: The value of the color to be created. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that resembles
-                the color you want to add.
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
+                resembles the color you want to add.
 
         Examples:
             Adding a new blue color to the palette:
@@ -713,7 +744,7 @@ class StackPalette:
             >>> spalette = StackPalette()
             >>> spalette.add("4287f5")
             >>> spalette[0]
-            HexRGB('#4287f5')
+            Hex('#4287f5')
         """
         self._color_stack.append(self.color_format.format(color))
 
@@ -723,7 +754,7 @@ class StackPalette:
         Args:
             index: Index of the color to be updated.
             color: The value of the color to be updated. Can be an instance of any
-                :mod:`~colorir.color` class or, alternatively, a color-like object that
+                :mod:`~colorir.color_class` class or, alternatively, a color-like object that
                 resembles the format of the color you want to update.
 
         Examples:
@@ -731,13 +762,13 @@ class StackPalette:
 
             >>> spalette = StackPalette(None, None, "dd0000")
             >>> spalette[0]
-            HexRGB('#dd0000')
+            Hex('#dd0000')
 
             Change it to be even a bit darker:
 
             >>> spalette.update(0, "800000")
             >>> spalette[0]
-            HexRGB('#800000')
+            Hex('#800000')
         """
         self._color_stack[index] = self.color_format.format(color)
 
@@ -796,6 +827,19 @@ class StackPalette:
         raise ValueError("'names' must have the same length as this 'StackPalette' and no "
                          "duplicates")
 
+    def to_cmap(self, N: int = None):
+        """Converts this stack palette into a matplotlib ListedColormap.
+
+        Args:
+            N: Passed down to ListedColormap constructor.
+        """
+        from matplotlib.colors import ListedColormap
+
+        colors = [color.hex(include_a=True, tail_a=True) for color in self.colors]
+        if self.name is None:
+            return ListedColormap(colors, N=N)
+        return ListedColormap(colors, N=N, name=self.name)
+
 
 def find_palettes(palettes_dir: str = None,
                   search_builtins=True,
@@ -859,50 +903,10 @@ def delete_palette(palette: str, palettes_dir: str = None):
         raise ValueError(f"palette name '{palette}' is ambiguous (more than one palette share it)")
 
 
-def swatch(obj: Union[ColorLike, List[ColorLike], Palette, StackPalette],
-           colored_text=True,
-           width=3,
-           height=1,
-           tabular=True):
-    """Prints swatches of `obj` in the terminal with colored text.
-
-    Each swatch consists of a rectangle of a color followed by its value (and name if known).
-
-    Args:
-        obj: What will be represented in the terminal. Is either a single color, a list of colors,
-            a :class:`Palette`, or a :class:`StackPalette`.
-        colored_text: Whether the text that follows the colored rectangles should also be colored.
-        width: The width (in space characters) of the colored rectangles.
-        height: The height (in number of lines) of the colored rectangles.
-        tabular: Whether the colored rectangle, color name and color value should be printed each
-            in its separate column. Only used if `obj` is a :class:`Palette`.
-    """
-    # Assume single ColorLike
-    if isinstance(obj, (ColorBase, str, tuple)):
-        obj = [obj]
-    if isinstance(obj, Palette):
-        longest_name = max([len(name) for name in obj.color_names])
-    # Needed to make Windows understand "\33" (https://stackoverflow.com/questions/12492810/python-
-    # how-can-i-make-the-ansi-escape-codes-to-work-also-in-windows)
-    os.system("")
-    for i, c_val in enumerate(obj):
-        rect_str = color_str(" " * width, bg_color=c_val)
-        val_str = f" {c_val}"
-        if isinstance(obj, Palette):
-            name = obj.color_names[i]
-            spacing = tabular * " " * (longest_name - len(name))
-            val_str = ' ' + name + spacing + val_str
-        if colored_text:
-            val_str = color_str(val_str, fg_color=c_val)
-        print(rect_str + val_str)
-        for _ in range(height - 1):
-            print(rect_str)
-
-
 # Common implementation of most_similar methods of Palette and StackPalette
 def _most_similar(palette, color, n):
     color = palette.color_format.format(color)
-    closest = sorted(palette.colors, key=lambda color2: simplified_dist(color, color2))
+    closest = sorted(palette.colors, key=lambda color2: utils.simplified_dist(color, color2))
     if n == 1:
         return closest[0]
     elif n < 0:
